@@ -1,4 +1,4 @@
-from .load import LoaderDGP, PostLoaderDGP
+from .load import LoaderDGP, PostLoaderDGP, PreLoaderDGP
 from .transform import TransformDGP
 from .enrich import EnricherDGP
 from .publish import PublisherDGP
